@@ -5,7 +5,14 @@ import json
 import pytest
 from syrupy.assertion import SnapshotAssertion
 
-from homewizard_energy.models import Device, Measurement, System, SystemUpdate
+from homewizard_energy.models import (
+    Batteries,
+    BatteriesUpdate,
+    Device,
+    Measurement,
+    System,
+    SystemUpdate,
+)
 
 from . import load_fixtures
 
@@ -16,6 +23,8 @@ pytestmark = [pytest.mark.asyncio]
     ("model", "fixtures"),
     [
         ("HWE-P1", ["device"]),
+        ("HWE-KWH1", ["device"]),
+        ("HWE-KWH3", ["device"]),
         ("HWE-BAT", ["device"]),
     ],
 )
@@ -40,6 +49,18 @@ async def test_device(model: str, fixtures: str, snapshot: SnapshotAssertion):
                 "measurement_invalid_external",
             ],
         ),
+        (
+            "HWE-KWH1",
+            [
+                "measurement",
+            ],
+        ),
+        (
+            "HWE-KWH3",
+            [
+                "measurement",
+            ],
+        ),
         (
             "HWE-BAT",
             [
@@ -71,6 +92,8 @@ async def test_measurement_ignores_invalid_tariff():
     ("model", "fixtures"),
     [
         ("HWE-P1", ["system"]),
+        ("HWE-KWH1", ["system"]),
+        ("HWE-KWH3", ["system"]),
         ("HWE-BAT", ["system"]),
     ],
 )
@@ -120,6 +143,42 @@ async def test_system_update_raises_when_none_set():
         update.to_dict()
 
 
+@pytest.mark.parametrize(
+    ("model", "fixtures"),
+    [
+        ("HWE-P1", ["batteries"]),
+        ("HWE-KWH1", ["batteries"]),
+        ("HWE-KWH3", ["batteries"]),
+    ],
+)
+async def test_batteries(model: str, fixtures: str, snapshot: SnapshotAssertion):
+    """Test Batteries model."""
+    for fixture in fixtures:
+        data = Batteries.from_dict(json.loads(load_fixtures(f"{model}/{fixture}.json")))
+        assert data
+
+        assert snapshot == data
+
+
+@pytest.mark.parametrize(
+    ("mode"),
+    [
+        Batteries.Mode.ZERO,
+        Batteries.Mode.TO_FULL,
+        Batteries.Mode.STANDBY,
+    ],
+)
+async def test_batteries_update(
+    mode: Batteries.Mode,
+    snapshot: SnapshotAssertion,
+):
+    """Test System update."""
+    data = BatteriesUpdate(
+        mode=mode,
+    )
+    assert snapshot == data.to_dict()
+
+
 # pylint: disable=too-many-arguments
 # pylint: disable=too-many-positional-arguments
 @pytest.mark.parametrize(
@@ -133,6 +192,8 @@ async def test_system_update_raises_when_none_set():
     ),
     [
         ("HWE-P1", False, True, True, True, True),
+        ("HWE-KWH1", False, False, True, True, False),
+        ("HWE-KWH3", False, False, True, True, False),
         ("HWE-BAT", False, True, False, False, False),
     ],
 )
